<template>
  <ToolHeader ref="toolHeader" />
  <div>
    <h1>IAILAB 平台主页</h1>
  </div>
  <el-skeleton :loading="loading" animated>
    <div id="app" v-for="(item, index) in appList" :key="`dynamics-${index}`">
      <div class="card" @click="gotoApp(item)">
        {{item.appName}}
      </div>
    </div>
  </el-skeleton>

</template>
<script lang="ts" setup>

import * as AppApi from '@/api/system/app'
import * as LoginApi from '@/api/login'
import ToolHeader from '@/layout/components/ToolHeader.vue'
import {Apps} from "@/views/Home/types";
import {CACHE_KEY, useCache} from "@/hooks/web/useCache";
import {usePermissionStore} from "@/store/modules/permission";
import {OAuth2Login, OAuth2TokenVO} from "@/api/system/oauth2/token";
import * as authUtil from "@/utils/auth";
import {CommonStatusEnum} from "@/utils/constants";
import * as UserApi from "@/api/system/user";
const permissionStore = usePermissionStore()
const { push } = useRouter()

const formData = ref({
  grantType: 'password',
  scope: 'user.read user.write',
  refreshToken: authUtil.getRefreshToken(),
  username: authUtil.getLoginForm().username,
  password: authUtil.getLoginForm().password,
  redirectUri: 'http://localhost:90',
})

defineOptions({ name: 'Home2' })

const { wsCache } = useCache()

const loading = ref(true)

let appList = reactive<Apps[]>([])

const getAppList = async () => {
  const data = await AppApi.getAppList()
  appList = Object.assign(appList, data)
}

const getAllApi = async () => {
  await Promise.all([
    getAppList()
  ])
  loading.value = false
}

getAllApi()

// 进入应用
const gotoApp = async (item) => {
  let appType = item.appType
  console.log(appType)
  if(appType === 1) {
    window.location.href = '/index'
  } else {
    // await OAuth2Login(formData.value)
    window.open('http://localhost:90/login?appid=' + item.appMenuId + "&username=" + authUtil.getLoginForm().username, '_blank')
  }
}

</script>

<style lang="scss" scoped>
#app{
  width: 300px;
  height: 140px;
  display: inline-block;
  background: transparent;
}
.card{
  width: 300px;
  height: 100px;
  padding: 30px;
  text-align: center;
  justify-content: center;
  font-size: 30px;
  font-weight: bolder;
  color: blue;
  background: aliceblue;
  border-radius: 10px;
}
</style>
